==> zio-aws-wafregional_3-5.17.121.3-sources.jar: zio/aws/wafregional/model/UpdateWebAclRequest.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.{ChangeToken, ResourceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateWebAclRequest(
    webACLId: ResourceId,
    changeToken: ChangeToken,
    updates: Option[Iterable[zio.aws.wafregional.model.WebACLUpdate]] = None,
    defaultAction: Option[zio.aws.wafregional.model.WafAction] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.UpdateWebAclRequest = {
    import UpdateWebAclRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
      .builder()
      .webACLId(ResourceId.unwrap(webACLId): java.lang.String)
      .changeToken(ChangeToken.unwrap(changeToken): java.lang.String)
      .optionallyWith(
        updates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.updates)
      .optionallyWith(defaultAction.map(value => value.buildAwsValue()))(
        _.defaultAction
      )
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly =
    zio.aws.wafregional.model.UpdateWebAclRequest.wrap(buildAwsValue())
}
object UpdateWebAclRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.UpdateWebAclRequest =
      zio.aws.wafregional.model.UpdateWebAclRequest(
        webACLId,
        changeToken,
        updates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        defaultAction.map(value => value.asEditable)
      )
    def webACLId: ResourceId
    def changeToken: ChangeToken
    def updates: Option[List[zio.aws.wafregional.model.WebACLUpdate.ReadOnly]]
    def defaultAction: Option[zio.aws.wafregional.model.WafAction.ReadOnly]
    def getWebACLId: ZIO[Any, Nothing, ResourceId] = ZIO.succeed(webACLId)
    def getChangeToken: ZIO[Any, Nothing, ChangeToken] =
      ZIO.succeed(changeToken)
    def getUpdates: ZIO[Any, AwsError, List[
      zio.aws.wafregional.model.WebACLUpdate.ReadOnly
    ]] = AwsError.unwrapOptionField("updates", updates)
    def getDefaultAction
        : ZIO[Any, AwsError, zio.aws.wafregional.model.WafAction.ReadOnly] =
      AwsError.unwrapOptionField("defaultAction", defaultAction)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ) extends zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly {
    override val webACLId: ResourceId =
      zio.aws.wafregional.model.primitives.ResourceId(impl.webACLId())
    override val changeToken: ChangeToken =
      zio.aws.wafregional.model.primitives.ChangeToken(impl.changeToken())
    override val updates
        : Option[List[zio.aws.wafregional.model.WebACLUpdate.ReadOnly]] = scala
      .Option(impl.updates())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.wafregional.model.WebACLUpdate.wrap(item)
        }.toList
      )
    override val defaultAction
        : Option[zio.aws.wafregional.model.WafAction.ReadOnly] = scala
      .Option(impl.defaultAction())
      .map(value => zio.aws.wafregional.model.WafAction.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ): zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-wafregional_3-6.20.162.2-sources.jar: zio/aws/wafregional/model/UpdateWebAclRequest.scala <==
package zio.aws.wafregional.model
import zio.aws.wafregional.model.primitives.{ChangeToken, ResourceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateWebAclRequest(
    webACLId: ResourceId,
    changeToken: ChangeToken,
    updates: Optional[Iterable[zio.aws.wafregional.model.WebACLUpdate]] =
      Optional.Absent,
    defaultAction: Optional[zio.aws.wafregional.model.WafAction] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.UpdateWebAclRequest = {
    import UpdateWebAclRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
      .builder()
      .webACLId(ResourceId.unwrap(webACLId): java.lang.String)
      .changeToken(ChangeToken.unwrap(changeToken): java.lang.String)
      .optionallyWith(
        updates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.updates)
      .optionallyWith(defaultAction.map(value => value.buildAwsValue()))(
        _.defaultAction
      )
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly =
    zio.aws.wafregional.model.UpdateWebAclRequest.wrap(buildAwsValue())
}
object UpdateWebAclRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.UpdateWebAclRequest =
      zio.aws.wafregional.model.UpdateWebAclRequest(
        webACLId,
        changeToken,
        updates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        defaultAction.map(value => value.asEditable)
      )
    def webACLId: ResourceId
    def changeToken: ChangeToken
    def updates: Optional[List[zio.aws.wafregional.model.WebACLUpdate.ReadOnly]]
    def defaultAction: Optional[zio.aws.wafregional.model.WafAction.ReadOnly]
    def getWebACLId: ZIO[Any, Nothing, ResourceId] = ZIO.succeed(webACLId)
    def getChangeToken: ZIO[Any, Nothing, ChangeToken] =
      ZIO.succeed(changeToken)
    def getUpdates: ZIO[Any, AwsError, List[
      zio.aws.wafregional.model.WebACLUpdate.ReadOnly
    ]] = AwsError.unwrapOptionField("updates", updates)
    def getDefaultAction
        : ZIO[Any, AwsError, zio.aws.wafregional.model.WafAction.ReadOnly] =
      AwsError.unwrapOptionField("defaultAction", defaultAction)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ) extends zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly {
    override val webACLId: ResourceId =
      zio.aws.wafregional.model.primitives.ResourceId(impl.webACLId())
    override val changeToken: ChangeToken =
      zio.aws.wafregional.model.primitives.ChangeToken(impl.changeToken())
    override val updates
        : Optional[List[zio.aws.wafregional.model.WebACLUpdate.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.updates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.wafregional.model.WebACLUpdate.wrap(item)
          }.toList
        )
    override val defaultAction
        : Optional[zio.aws.wafregional.model.WafAction.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.defaultAction())
        .map(value => zio.aws.wafregional.model.WafAction.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.UpdateWebAclRequest
  ): zio.aws.wafregional.model.UpdateWebAclRequest.ReadOnly = new Wrapper(impl)
}
